This crate contains kube-rs compatible bindings for Kubernetes custom resources for the kyverno.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
kyverno.io/v1
ClusterPolicyPolicy
kyverno.io/v1alpha2
AdmissionReportBackgroundScanReportClusterAdmissionReportClusterBackgroundScanReport
kyverno.io/v1beta1
UpdateRequest
kyverno.io/v2
AdmissionReportBackgroundScanReportCleanupPolicyClusterAdmissionReportClusterBackgroundScanReportClusterCleanupPolicyGlobalContextEntryPolicyExceptionUpdateRequest
kyverno.io/v2alpha1
CELPolicyExceptionCleanupPolicyClusterCleanupPolicyGlobalContextEntryPolicyExceptionValidatingPolicy
kyverno.io/v2beta1
CleanupPolicyClusterCleanupPolicyClusterPolicyGlobalContextEntryPolicyPolicyException